==> index-service-1.0.0-20140327.141136-2-sources.jar: org/gcube/rest/index/service/IndexClientWrapper.java <==
package org.gcube.rest.index.service;

import gr.uoa.di.madgik.rr.ResourceRegistryException;

import java.io.InputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.Set;

import org.gcube.elasticsearch.FullTextNode;
import org.gcube.rest.index.common.Constants;
import org.gcube.rest.index.common.discover.IndexDiscovererAPI;
import org.gcube.rest.index.common.resources.IndexResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.io.Resources;


public class IndexClientWrapper implements Serializable {
	private static final long serialVersionUID = 1L;
	
	private static final String MAXIMUM_FRAGMENT_CNT = "maxFragmentCnt";
	private static final String MAXIMUM_FRAGMENT_SIZE = "maxFragmentSize";
	private static final String NO_REPLICAS = "noReplicas";
	private static final String NO_SHARDS = "noShards";
	private static final String ELASTICSEARCH_PORT = "elasticSearchPort";
	private static final String USE_CLUSTER_ID = "useClusterId";
	private static final String USE_RRADAPTOR = "useRRAdaptor";
	private static final String DATA_DIRECTORY = "dataDir";
	private static final String MAX_RESULTS = "maxResults";
	private static final String HOSTNAME = "hostname";
	
	private FullTextNode ftn;
	
	private static final Logger logger = LoggerFactory.getLogger(IndexClientWrapper.class);
	
	
	private String clusterID;
	private String scope;
	private IndexDiscovererAPI<IndexResource> indexDiscoverer;
	
	public String getClusterID() {
		return this.clusterID;
	}

	public void setClusterID(String clusterID) {
		this.clusterID = clusterID;
	}

	//@Inject
	public IndexClientWrapper(IndexDiscovererAPI<IndexResource> indexDiscoverer, String scope) {
		logger.info("Creating a new FullTextNodeClient with indexDiscoverer : " + indexDiscoverer);
		this.indexDiscoverer = indexDiscoverer;
		this.scope = scope;
	}
	
	public void initialize() throws ResourceRegistryException, InterruptedException {
		try {
			final Properties properties = new Properties();
			try (InputStream is = Resources.getResource(Constants.PROPERTIES_FILE).openStream()) {
				properties.load(is);
			} catch (Exception e) {
				throw new IllegalArgumentException("could not load property file  : " + Constants.PROPERTIES_FILE);
			}
			
			Integer fragm_cnt = Integer.valueOf(properties.getProperty(MAXIMUM_FRAGMENT_CNT).trim());
			Integer fragm_size = Integer.valueOf(properties.getProperty(MAXIMUM_FRAGMENT_SIZE).trim());
			Integer noReplicas = Integer.valueOf(properties.getProperty(NO_REPLICAS).trim());
			Integer noShards = Integer.valueOf(properties.getProperty(NO_SHARDS).trim());
			Integer esPort = Integer.valueOf(properties.getProperty(ELASTICSEARCH_PORT).trim());
			Integer maxResults = null;
			
			try {
				maxResults = Integer.valueOf(properties.getProperty(MAX_RESULTS).trim());
			} catch (Exception e) {
				logger.info("maxResults not given");
			}
			
			Boolean useClusterID = Boolean.valueOf(properties.getProperty(USE_CLUSTER_ID));
			String dataDirectory = properties.getProperty(DATA_DIRECTORY);
			Boolean useRRAdaptor = Boolean.valueOf(properties.getProperty(USE_RRADAPTOR));
			String hostname = properties.getProperty(HOSTNAME);
			
			logger.info("Data read from jndi");
			logger.info("fragm_cnt           : " + fragm_cnt);
			logger.info("fragm_size          : " + fragm_size);
			logger.info("noReplicas          : " + noReplicas);
			logger.info("noShards            : " + noShards);
			logger.info("esPort              : " + esPort);
			logger.info("useClusterID        : " + useClusterID);
			logger.info("dataDirectory       : " + dataDirectory);
			logger.info("useRRAdaptor        : " + useRRAdaptor);
			logger.info("maxResults          : " + maxResults);
			logger.info("hostname            : " + hostname);
			
			String dataDir = null;
			
			if (dataDirectory != null) {
				dataDir = dataDirectory;
			} else {
				dataDir = "./indexData/elasticsearch/";
			}
			
			logger.info("Setting index scope to " + this.scope);
			
			
			String clusterName = "elastic-search-cluster-service-";
			if (useClusterID == Boolean.FALSE)
				this.clusterID = this.scope;
			
			clusterName += this.clusterID;
			
			logger.info("initializing fulltextnode...");
			
			if (useRRAdaptor == Boolean.FALSE)
				this.ftn = new FullTextNode(hostname, dataDir, clusterName, "main-index", noReplicas, noShards, this.scope, fragm_cnt, fragm_size, Boolean.FALSE);
			else
				this.ftn = new FullTextNode(hostname, dataDir, clusterName, "main-index", noReplicas, noShards, this.scope, fragm_cnt, fragm_size);
			
			logger.info("initializing fulltextnode...OK");
			
			if (maxResults != null)
				this.ftn.setMaxResults(maxResults);
			
			logger.info("discovering fulltextindex nodes...");
			//TODO: discover resources and get elasticsearch port (es port should be updated when a resource is created/loaded
			Set<IndexResource> resources = this.indexDiscoverer.discoverFulltextIndexNodeResources(this.clusterID);
			
			List<String> knownNodes = new ArrayList<String>();
			if (resources == null || resources.size() == 0) {
				logger.warn("No other resources found. is this the first one?");
			} else {
				for (IndexResource resource : resources){
					if (resource.getEsTransportAddress() != null)
						knownNodes.add(resource.getEsTransportAddress());
				}
			}
			
			logger.info("discovering fulltextindex nodes...OK");
			logger.info("knownNodes : "+knownNodes);
			
			if(knownNodes.size()>0)
				this.ftn.joinCluster(knownNodes);
			else
				this.ftn.createOrJoinCluster();
			
			this.ftn.addMetaIndex();
			this.ftn.refreshIndexTypesOfIndex();
			
		} catch (ResourceRegistryException e) {
			throw e;
		} catch (InterruptedException e) {
			throw e;
		} catch (Exception e) {
			logger.error("error while initializing the index client", e);
		}
	}

	public FullTextNode getFullTextNode()
	{
		return this.ftn;
	}
	
	public String getScope()
	{
		return this.ftn.getScope();
	}
	
	public String getClusterName()
	{
		return this.ftn.getClusterName();
	}
	
}

==> index-service-1.0.0-20140328.102357-3-sources.jar: org/gcube/rest/index/service/IndexClientWrapper.java <==
package org.gcube.rest.index.service;

import gr.uoa.di.madgik.rr.ResourceRegistryException;

import java.io.InputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.Set;

import org.gcube.elasticsearch.FullTextNode;
import org.gcube.rest.index.common.Constants;
import org.gcube.rest.index.common.discover.IndexDiscovererAPI;
import org.gcube.rest.index.common.resources.IndexResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.io.Resources;


public class IndexClientWrapper implements Serializable {
	private static final long serialVersionUID = 1L;
	
	private static final String MAXIMUM_FRAGMENT_CNT = "maxFragmentCnt";
	private static final String MAXIMUM_FRAGMENT_SIZE = "maxFragmentSize";
	private static final String NO_REPLICAS = "noReplicas";
	private static final String NO_SHARDS = "noShards";
	private static final String ELASTICSEARCH_PORT = "elasticSearchPort";
	private static final String USE_CLUSTER_ID = "useClusterId";
	private static final String USE_RRADAPTOR = "useRRAdaptor";
	private static final String DATA_DIRECTORY = "dataDir";
	private static final String MAX_RESULTS = "maxResults";
	private static final String HOSTNAME = "hostname";
	
	private FullTextNode ftn;
	
	private static final Logger logger = LoggerFactory.getLogger(IndexClientWrapper.class);
	
	
	private String clusterID;
	private String scope;
	private IndexDiscovererAPI<IndexResource> indexDiscoverer;
	
	public String getClusterID() {
		return this.clusterID;
	}

	public void setClusterID(String clusterID) {
		this.clusterID = clusterID;
	}

	//@Inject
	public IndexClientWrapper(IndexDiscovererAPI<IndexResource> indexDiscoverer, String scope) {
		logger.info("Creating a new FullTextNodeClient with indexDiscoverer : " + indexDiscoverer);
		this.indexDiscoverer = indexDiscoverer;
		this.scope = scope;
	}
	
	public void initialize() throws ResourceRegistryException, InterruptedException {
		try {
			final Properties properties = new Properties();
			try (InputStream is = Resources.getResource(Constants.PROPERTIES_FILE).openStream()) {
				properties.load(is);
			} catch (Exception e) {
				throw new IllegalArgumentException("could not load property file  : " + Constants.PROPERTIES_FILE);
			}
			
			Integer fragm_cnt = Integer.valueOf(properties.getProperty(MAXIMUM_FRAGMENT_CNT).trim());
			Integer fragm_size = Integer.valueOf(properties.getProperty(MAXIMUM_FRAGMENT_SIZE).trim());
			Integer noReplicas = Integer.valueOf(properties.getProperty(NO_REPLICAS).trim());
			Integer noShards = Integer.valueOf(properties.getProperty(NO_SHARDS).trim());
			Integer esPort = Integer.valueOf(properties.getProperty(ELASTICSEARCH_PORT).trim());
			Integer maxResults = null;
			
			try {
				maxResults = Integer.valueOf(properties.getProperty(MAX_RESULTS).trim());
			} catch (Exception e) {
				logger.info("maxResults not given");
			}
			
			Boolean useClusterID = Boolean.valueOf(properties.getProperty(USE_CLUSTER_ID));
			String dataDirectory = properties.getProperty(DATA_DIRECTORY);
			Boolean useRRAdaptor = Boolean.valueOf(properties.getProperty(USE_RRADAPTOR));
			String hostname = properties.getProperty(HOSTNAME);
			
			logger.info("Data read from jndi");
			logger.info("fragm_cnt           : " + fragm_cnt);
			logger.info("fragm_size          : " + fragm_size);
			logger.info("noReplicas          : " + noReplicas);
			logger.info("noShards            : " + noShards);
			logger.info("esPort              : " + esPort);
			logger.info("useClusterID        : " + useClusterID);
			logger.info("dataDirectory       : " + dataDirectory);
			logger.info("useRRAdaptor        : " + useRRAdaptor);
			logger.info("maxResults          : " + maxResults);
			logger.info("hostname            : " + hostname);
			
			String dataDir = null;
			
			if (dataDirectory != null) {
				dataDir = dataDirectory;
			} else {
				dataDir = "./indexData/elasticsearch/";
			}
			
			logger.info("Setting index scope to " + this.scope);
			
			
			String clusterName = "elastic-search-cluster-service-";
			if (useClusterID == Boolean.FALSE)
				this.clusterID = this.scope;
			
			clusterName += this.clusterID;
			
			logger.info("initializing fulltextnode...");
			
			if (useRRAdaptor == Boolean.FALSE)
				this.ftn = new FullTextNode(hostname, dataDir, clusterName, "main-index", noReplicas, noShards, this.scope, fragm_cnt, fragm_size, Boolean.FALSE);
			else
				this.ftn = new FullTextNode(hostname, dataDir, clusterName, "main-index", noReplicas, noShards, this.scope, fragm_cnt, fragm_size);
			
			logger.info("initializing fulltextnode...OK");
			
			if (maxResults != null)
				this.ftn.setMaxResults(maxResults);
			
			logger.info("discovering fulltextindex nodes...");
			//TODO: discover resources and get elasticsearch port (es port should be updated when a resource is created/loaded
			Set<IndexResource> resources = this.indexDiscoverer.discoverFulltextIndexNodeResources(this.clusterID, null);
			
			List<String> knownNodes = new ArrayList<String>();
			if (resources == null || resources.size() == 0) {
				logger.warn("No other resources found. is this the first one?");
			} else {
				for (IndexResource resource : resources){
					if (resource.getEsTransportAddress() != null)
						knownNodes.add(resource.getEsTransportAddress());
				}
			}
			
			logger.info("discovering fulltextindex nodes...OK");
			logger.info("knownNodes : "+knownNodes);
			
			if(knownNodes.size()>0)
				this.ftn.joinCluster(knownNodes);
			else
				this.ftn.createOrJoinCluster();
			
			this.ftn.addMetaIndex();
			this.ftn.refreshIndexTypesOfIndex();
			
		} catch (ResourceRegistryException e) {
			throw e;
		} catch (InterruptedException e) {
			throw e;
		} catch (Exception e) {
			logger.error("error while initializing the index client", e);
		}
	}

	public FullTextNode getFullTextNode()
	{
		return this.ftn;
	}
	
	public String getScope()
	{
		return this.ftn.getScope();
	}
	
	public String getClusterName()
	{
		return this.ftn.getClusterName();
	}
	
}
